=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2005-10-06 02:17:49 +0000
+++ bzrlib/branch.py	2005-10-06 06:31:33 +0000
@@ -34,7 +34,7 @@
                            DivergedBranches, LockError, UnlistableStore,
                            UnlistableBranch, NoSuchFile)
 from bzrlib.textui import show_status
-from bzrlib.revision import Revision, is_ancestor
+from bzrlib.revision import Revision
 from bzrlib.delta import compare_trees
 from bzrlib.tree import EmptyTree, RevisionTree
 from bzrlib.inventory import Inventory
@@ -780,15 +780,17 @@
         # But for now, just hash the contents.
         return bzrlib.osutils.sha_file(self.get_revision_xml_file(revision_id))
 
-    def _get_ancestry_weave(self):
-        return self.control_weaves.get_weave('ancestry')
-
     def get_ancestry(self, revision_id):
-        """Return a list of revision-ids integrated by a revision."""
+        """Return a list of revision-ids integrated by a revision.
+        
+        This currently returns a list, but the ordering is not guaranteed:
+        treat it as a set.
+        """
         if revision_id is None:
             return [None]
-        w = self._get_ancestry_weave()
-        return [None] + [l[:-1] for l in w.get_iter(w.lookup(revision_id))]
+        w = self.control_weaves.get_weave('inventory')
+        return [None] + map(w.idx_to_name,
+                            w.inclusions([w.lookup(revision_id)]))
 
     def get_inventory_weave(self):
         return self.control_weaves.get_weave('inventory')

=== modified file 'bzrlib/clone.py'
--- bzrlib/clone.py	2005-10-04 04:49:21 +0000
+++ bzrlib/clone.py	2005-10-06 06:31:33 +0000
@@ -117,7 +117,7 @@
 def _copy_control_weaves(branch_from, branch_to):
     to_control = branch_to.control_weaves
     from_control = branch_from.control_weaves
-    to_control.copy_multi(from_control, ['inventory', 'ancestry'])
+    to_control.copy_multi(from_control, ['inventory'])
 
     
 def copy_branch_slower(branch_from, to_location, revision=None, basis_branch=None):

=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2005-10-06 02:51:02 +0000
+++ bzrlib/commit.py	2005-10-06 06:31:33 +0000
@@ -219,7 +219,6 @@
                 raise PointlessCommit()
 
             self._record_inventory()
-            self._record_ancestry()
             self._make_revision()
             note('committed r%d {%s}', (self.branch.revno() + 1),
                  self.rev_id)
@@ -255,26 +254,6 @@
         if escape_count:
             note("replaced %d control characters in message", escape_count)
 
-    def _record_ancestry(self):
-        """Append merged revision ancestry to the ancestry file.
-
-        This should be the merged ancestry of all parents, plus the
-        new revision id."""
-        s = self.branch.control_weaves
-        w = s.get_weave_or_empty('ancestry')
-        lines = self._make_ancestry(w)
-        w.add(self.rev_id, self.present_parents, lines)
-        s.put_weave('ancestry', w)
-
-    def _make_ancestry(self, ancestry_weave):
-        """Return merged ancestry lines.
-
-        The lines are revision-ids followed by newlines."""
-        parent_ancestries = [ancestry_weave.get(p) for p in self.present_parents]
-        new_lines = merge_ancestry_lines(self.rev_id, parent_ancestries)
-        mutter('merged ancestry of {%s}:\n%s', self.rev_id, ''.join(new_lines))
-        return new_lines
-
     def _gather_parents(self):
         """Record the parents of a merge for merge detection."""
         pending_merges = self.branch.pending_merges()
@@ -315,7 +294,6 @@
         self.branch.revision_store.add(rev_tmp, self.rev_id)
         mutter('new revision_id is {%s}', self.rev_id)
 
-
     def _remove_deleted(self):
         """Remove deleted files from the working inventories.
 
@@ -397,36 +375,8 @@
             if file_id not in self.new_inv:
                 note('deleted %s', self.basis_inv.id2path(file_id))
 
-
-
 def _gen_revision_id(branch, when):
     """Return new revision-id."""
     s = '%s-%s-' % (user_email(branch), compact_date(when))
     s += hexlify(rand_bytes(8))
     return s
-
-
-
-    
-def merge_ancestry_lines(rev_id, ancestries):
-    """Return merged ancestry lines.
-
-    rev_id -- id of the new revision
-    
-    ancestries -- a sequence of ancestries for parent revisions,
-        as newline-terminated line lists.
-    """
-    if len(ancestries) == 0:
-        return [rev_id + '\n']
-    seen = set(ancestries[0])
-    ancs = ancestries[0][:]    
-    for parent_ancestry in ancestries[1:]:
-        for line in parent_ancestry:
-            assert line[-1] == '\n'
-            if line not in seen:
-                ancs.append(line)
-                seen.add(line)
-    r = rev_id + '\n'
-    assert r not in seen
-    ancs.append(r)
-    return ancs

=== modified file 'bzrlib/fetch.py'
--- bzrlib/fetch.py	2005-10-05 10:02:53 +0000
+++ bzrlib/fetch.py	2005-10-06 06:31:33 +0000
@@ -190,7 +190,6 @@
             if not self.to_branch.has_revision(parent):
                 parents.pop(parents.index(parent))
         self._copy_inventory(rev_id, inv_xml, parents)
-        self._copy_ancestry(rev_id, parents)
         self.to_branch.revision_store.add(StringIO(rev_xml), rev_id)
         mutter('copied revision %s', rev_id)
 
@@ -199,13 +198,6 @@
         self.to_control.add_text('inventory', rev_id,
                                 split_lines(inv_xml), parent_ids)
 
-
-    def _copy_ancestry(self, rev_id, parent_ids):
-        ancestry_lines = self.from_control.get_lines('ancestry', rev_id)
-        self.to_control.add_text('ancestry', rev_id, ancestry_lines,
-                                 parent_ids)
-
-        
     def _copy_new_texts(self, rev_id, inv):
         """Copy any new texts occuring in this revision."""
         # TODO: Rather than writing out weaves every time, hold them

=== modified file 'bzrlib/selftest/test_ancestry.py'
--- bzrlib/selftest/test_ancestry.py	2005-09-27 07:24:40 +0000
+++ bzrlib/selftest/test_ancestry.py	2005-10-06 06:31:33 +0000
@@ -39,6 +39,9 @@
                  rev_id='tester@foo--2')
 
         ancs = b.get_ancestry('tester@foo--2')
+        self.assertEqual([None, 'tester@foo--1', 'tester@foo--2'], ancs)
+        self.assertEqual([None, 'tester@foo--1'], 
+                         b.get_ancestry('tester@foo--1'))
 
     def test_none_is_always_an_ancestor(self):
         b = Branch.initialize('.')

=== modified file 'bzrlib/selftest/testfetch.py'
--- bzrlib/selftest/testfetch.py	2005-10-05 06:44:02 +0000
+++ bzrlib/selftest/testfetch.py	2005-10-06 06:31:33 +0000
@@ -56,7 +56,7 @@
     assert has_revision(br_a, br_b.revision_history()[5])
 
     # When a non-branch ancestor is missing, it should be unlisted...
-    # as its not present in the ancestry weave.
+    # as its not reference from the inventory weave.
     br_b4 = new_branch('br_4')
     count, failures = greedy_fetch(br_b4, br_b)
     self.assertEqual(count, 7)

=== modified file 'bzrlib/upgrade.py'
--- bzrlib/upgrade.py	2005-10-06 02:51:02 +0000
+++ bzrlib/upgrade.py	2005-10-06 06:31:33 +0000
@@ -95,7 +95,6 @@
 from bzrlib.xml5 import serializer_v5
 from bzrlib.trace import mutter, note, warning, enable_default_logging
 from bzrlib.osutils import sha_strings, sha_string
-from bzrlib.commit import merge_ancestry_lines
 
 
 class Convert(object):
@@ -119,8 +118,6 @@
         if not os.path.isdir(self.base + '/.bzr/weaves'):
             os.mkdir(self.base + '/.bzr/weaves')
         self.inv_weave = Weave('inventory')
-        self.anc_weave = Weave('ancestry')
-        self.ancestries = {}
         # holds in-memory weaves for all files
         self.text_weaves = {}
         os.remove(self.branch.controlfilename('branch-format'))
@@ -197,7 +194,6 @@
 
     def _write_all_weaves(self):
         write_a_weave(self.inv_weave, self.base + '/.bzr/inventory.weave')
-        write_a_weave(self.anc_weave, self.base + '/.bzr/ancestry.weave')
         i = 0
         try:
             for file_id, file_weave in self.text_weaves.items():
@@ -273,7 +269,6 @@
                            if p not in self.absent_revisions]
         self._convert_revision_contents(rev, inv, present_parents)
         self._store_new_weave(rev, inv, present_parents)
-        self._make_rev_ancestry(rev, present_parents)
         self.converted_revs.add(rev_id)
 
 
@@ -295,24 +290,6 @@
                            new_inv_sha1)
         rev.inventory_sha1 = new_inv_sha1
 
-
-    def _make_rev_ancestry(self, rev, present_parents):
-        rev_id = rev.revision_id
-        for parent_id in present_parents:
-            assert parent_id in self.converted_revs
-        if present_parents:
-            lines = list(self.anc_weave.mash_iter(present_parents))
-        else:
-            lines = []
-        lines.append(rev_id + '\n')
-        if __debug__:
-            parent_ancestries = [self.ancestries[p] for p in present_parents]
-            new_lines = merge_ancestry_lines(rev_id, parent_ancestries)
-            assert set(lines) == set(new_lines)
-            self.ancestries[rev_id] = new_lines
-        self.anc_weave.add(rev_id, present_parents, lines)
-
-
     def _convert_revision_contents(self, rev, inv, present_parents):
         """Convert all the files within a revision.
 

